python-bogus-project-honeypot
-----------------------------

.. image:: https://badge.fury.io/py/python-bogus-project-honeypot.svg
        :target: https://pypi.python.org/pypi/python-bogus-project-honeypot


This project releases automatically on PyPi... by a bot. It's then downloaded by bots and mirrors.

If you want to be a real jerk, download it.

Why is this project necessary?
------------------------------

To correct statistics.

Thousands of hits are generated by bots and mirrors, often way more than humans create. This makes it very difficult to collect statistics from PyPi.

The great maintainers of PyPi should not suffer anymore headaches inflicted by bots and mirrors. We as a community can try to provide a meaningful service for correcting those statistics already offered.
